@@ -1,19 +1,20 @@
 '''
 [![npm version](https://badge.fury.io/js/cdk-github.svg)](https://badge.fury.io/js/cdk-github)
 [![PyPI version](https://badge.fury.io/py/cdk-github.svg)](https://badge.fury.io/py/cdk-github)
+[![NuGet version](https://badge.fury.io/nu/CdkGithub.svg)](https://badge.fury.io/nu/CdkGithub)
 [![release](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml/badge.svg)](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml)
 ![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
 
 # CDK-GitHub
 
-[AWS CDK](https://aws.amazon.com/cdk/) v2 L3 constructs for GitHub.
+GitHub Constructs for use in [AWS CDK](https://aws.amazon.com/cdk/) .
 
 This project aims to make GitHub's API accessible through CDK with various helper constructs to create resources in GitHub.
-The target is to replicate most of the functionality of the [Terraform GitHub Provider](https://registry.terraform.io/providers/integrations/github/latest/docs).
+The target is to replicate most of the functionality of the official [Terraform GitHub Provider](https://registry.terraform.io/providers/integrations/github/latest/docs).
 
-Internally [AWS CloudFormation custom resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-custom-resources.html) will be used to track GitHub resources (such as Secrets).
+Internally [AWS CloudFormation custom resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-custom-resources.html) and [octokit](https://github.com/octokit/core.js) are used to manage GitHub resources (such as Secrets).
 
-# Installation
+# 🔧 Installation
 
 JavaScript/TypeScript:
 `npm install cdk-github`
@@ -21,24 +22,28 @@ JavaScript/TypeScript:
 Python:
 `pip install cdk-github`
 
-# Constructs
+# 📚 Constructs
 
 This library provides the following constructs:
 
 * [ActionSecret](API.md#actionsecret-a-nameactionsecret-idcdk-githubactionsecreta) - Creates a [GitHub Action (repository) secret](https://docs.github.com/en/actions/security-guides/encrypted-secrets#creating-encrypted-secrets-for-a-repository) from a given AWS Secrets Manager secret.
 * [ActionEnvironmentSecret](API.md#actionenvironmentsecret-a-nameactionenvironmentsecret-idcdk-githubactionenvironmentsecreta) - Creates a [GitHub Action environment secret](https://docs.github.com/en/actions/security-guides/encrypted-secrets#creating-encrypted-secrets-for-an-environment) from a given AWS Secrets Manager secret.
 
-# Authentication
+# 🔓 Authentication
 
 Currently the constructs only support authentication via a [GitHub Personal Access Token](https://github.com/settings/tokens/new). The token needs to be a stored in a AWS SecretsManager Secret and passed to the construct as parameter.
 
-# Examples
+# 👩‍🏫 Examples
+
+The API documentation and examples in different languages are available on [Construct Hub](https://constructs.dev/packages/cdk-github).
+All (typescript) examples can be found in the folder [examples](src/examples/).
 
 ## ActionSecret
 
-### TypeScript
-
 ```python
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
+import { Construct } from 'constructs';
 import { ActionSecret } from 'cdk-github';
 
 export class ActionSecretStack extends Stack {
@@ -59,37 +64,12 @@ export class ActionSecretStack extends Stack {
 }
 ```
 
-See full example in [ActionSecretStack](src/examples/action-secret/action-secret-stack.ts)
-
-### Python
-
-```python
-import cdkgithub
-
-class ActionSecretStack(Stack):
-    def __init__(self, scope: Construct, construct_id: str, **kwargs) -> None:
-        super().__init__(scope, construct_id, **kwargs)
-
-        source_secret = sm.Secret.from_secret_name_v2(
-            self, "secretToStoreInGitHub", "testcdkgithub"
-        )
-        github_token_secret = sm.Secret.from_secret_name_v2(
-            self, "ghSecret", "GITHUB_TOKEN"
-        )
-        cdkgithub.ActionSecret(
-            self,
-            "GitHubActionSecret",
-            github_token_secret=github_token_secret,
-            repository_name="cdk-github",
-            repository_owner="wtfjoke",
-            repository_secret_name="aRandomPythonGitHubSecret",
-            source_secret=source_secret,
-        )
-```
-
 ## ActionEnvironmentSecret
 
 ```python
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
+import { Construct } from 'constructs';
 import { ActionEnvironmentSecret } from 'cdk-github';
 
 export class ActionEnvironmentSecretStack extends Stack {
@@ -111,7 +91,9 @@ export class ActionEnvironmentSecretStack extends Stack {
 }
 ```
 
-See full example in [ActionEnvironmentSecretStack](src/examples/action-environment-secret/action-environment-secret-stack.ts)
+# 💖 Contributing
+
+Contributions of all kinds are welcome! Check out our [contributing guide](CONTRIBUTING.md).
 '''
 import abc
 import builtins
@@ -134,6 +116,10 @@ class ActionEnvironmentSecret(
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-github.ActionEnvironmentSecret",
 ):
+    '''
+    :stability: experimental
+    '''
+
     def __init__(
         self,
         scope: constructs.Construct,
@@ -149,12 +135,14 @@ class ActionEnvironmentSecret(
         '''
         :param scope: -
         :param id: -
-        :param environment: The GithHub environment which the secret should be stored in.
-        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: The GitHub repository name.
-        :param repository_owner: The GitHub repository owner.
-        :param repository_secret_name: The GitHub secret name to be stored.
-        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
+        :param environment: (experimental) The GithHub environment name which the secret should be stored in.
+        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: (experimental) The GitHub repository name.
+        :param repository_owner: (experimental) The GitHub repository owner.
+        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
+        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+
+        :stability: experimental
         '''
         props = ActionEnvironmentSecretProps(
             environment=environment,
@@ -192,12 +180,14 @@ class ActionEnvironmentSecretProps:
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
     ) -> None:
         '''
-        :param environment: The GithHub environment which the secret should be stored in.
-        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: The GitHub repository name.
-        :param repository_owner: The GitHub repository owner.
-        :param repository_secret_name: The GitHub secret name to be stored.
-        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
+        :param environment: (experimental) The GithHub environment name which the secret should be stored in.
+        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: (experimental) The GitHub repository name.
+        :param repository_owner: (experimental) The GitHub repository owner.
+        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
+        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+
+        :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "environment": environment,
@@ -210,42 +200,60 @@ class ActionEnvironmentSecretProps:
 
     @builtins.property
     def environment(self) -> builtins.str:
-        '''The GithHub environment which the secret should be stored in.'''
+        '''(experimental) The GithHub environment name which the secret should be stored in.
+
+        :stability: experimental
+        '''
         result = self._values.get("environment")
         assert result is not None, "Required property 'environment' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''The AWS secret in which the OAuth GitHub (personal) access token is stored.'''
+        '''(experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
+
+        :stability: experimental
+        '''
         result = self._values.get("github_token_secret")
         assert result is not None, "Required property 'github_token_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
     @builtins.property
     def repository_name(self) -> builtins.str:
-        '''The GitHub repository name.'''
+        '''(experimental) The GitHub repository name.
+
+        :stability: experimental
+        '''
         result = self._values.get("repository_name")
         assert result is not None, "Required property 'repository_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_owner(self) -> builtins.str:
-        '''The GitHub repository owner.'''
+        '''(experimental) The GitHub repository owner.
+
+        :stability: experimental
+        '''
         result = self._values.get("repository_owner")
         assert result is not None, "Required property 'repository_owner' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
-        '''The GitHub secret name to be stored.'''
+        '''(experimental) The GitHub secret name to be stored.
+
+        :stability: experimental
+        '''
         result = self._values.get("repository_secret_name")
         assert result is not None, "Required property 'repository_secret_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def source_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''The AWS secret which should be stored as a GitHub as a secret.'''
+        '''(experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+
+        :stability: experimental
+        '''
         result = self._values.get("source_secret")
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
@@ -267,6 +275,10 @@ class ActionSecret(
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-github.ActionSecret",
 ):
+    '''
+    :stability: experimental
+    '''
+
     def __init__(
         self,
         scope: constructs.Construct,
@@ -281,11 +293,13 @@ class ActionSecret(
         '''
         :param scope: -
         :param id: -
-        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: The GitHub repository name.
-        :param repository_owner: The GitHub repository owner.
-        :param repository_secret_name: The GitHub secret name to be stored.
-        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
+        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: (experimental) The GitHub repository name.
+        :param repository_owner: (experimental) The GitHub repository owner.
+        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
+        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+
+        :stability: experimental
         '''
         props = ActionSecretProps(
             github_token_secret=github_token_secret,
@@ -320,11 +334,13 @@ class ActionSecretProps:
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
     ) -> None:
         '''
-        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: The GitHub repository name.
-        :param repository_owner: The GitHub repository owner.
-        :param repository_secret_name: The GitHub secret name to be stored.
-        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
+        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: (experimental) The GitHub repository name.
+        :param repository_owner: (experimental) The GitHub repository owner.
+        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
+        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+
+        :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "github_token_secret": github_token_secret,
@@ -336,35 +352,50 @@ class ActionSecretProps:
 
     @builtins.property
     def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''The AWS secret in which the OAuth GitHub (personal) access token is stored.'''
+        '''(experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
+
+        :stability: experimental
+        '''
         result = self._values.get("github_token_secret")
         assert result is not None, "Required property 'github_token_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
     @builtins.property
     def repository_name(self) -> builtins.str:
-        '''The GitHub repository name.'''
+        '''(experimental) The GitHub repository name.
+
+        :stability: experimental
+        '''
         result = self._values.get("repository_name")
         assert result is not None, "Required property 'repository_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_owner(self) -> builtins.str:
-        '''The GitHub repository owner.'''
+        '''(experimental) The GitHub repository owner.
+
+        :stability: experimental
+        '''
         result = self._values.get("repository_owner")
         assert result is not None, "Required property 'repository_owner' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
-        '''The GitHub secret name to be stored.'''
+        '''(experimental) The GitHub secret name to be stored.
+
+        :stability: experimental
+        '''
         result = self._values.get("repository_secret_name")
         assert result is not None, "Required property 'repository_secret_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def source_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''The AWS secret which should be stored as a GitHub as a secret.'''
+        '''(experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+
+        :stability: experimental
+        '''
         result = self._values.get("source_secret")
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
